@@ -73,7 +73,9 @@ class Trap:
 
 
 class TrapLocations:
-    def __init__(self, initial_location, tile_size, max_size=1200, drifts=[]):
+    def __init__(self, initial_location, tile_size, max_size=1200, drifts=None):
+        if drifts is None:
+            drifts = []
         self.tile_size = tile_size
         self.max_size = max_size
         self.initial_location = initial_location
@@ -82,14 +84,14 @@ class TrapLocations:
         ]
         self.drifts = drifts
 
-    @classmethod
-    def from_source(cls, fpath: str):
-        with h5py.File(fpath, "r") as f:
-            # TODO read tile size from file metadata
-            drifts = f["trap_info/drifts"][()]
-            tlocs = cls(f["trap_info/trap_locations"][()], tile_size=96, drifts=drifts)
+        # @classmethod
+        # def from_source(cls, fpath: str):
+        #     with h5py.File(fpath, "r") as f:
+        #         # TODO read tile size from file metadata
+        #         drifts = f["trap_info/drifts"][()].tolist()
+        #         tlocs = cls(f["trap_info/trap_locations"][()], tile_size=96, drifts=drifts)
 
-        return tlocs
+        # return tlocs
 
     @property
     def shape(self):
@@ -111,38 +113,30 @@ class TrapLocations:
             res["attrs/tile_size"] = self.tile_size
             res["attrs/max_size"] = self.max_size
         res["drifts"] = np.expand_dims(self.drifts[tp], axis=0)
-        # res['processed_timepoints'] = tp
+        # res["processed_timepoints"] = tp
         return res
 
+    @classmethod
+    def from_tiler_init(cls, initial_location, tile_size, max_size=1200):
+        return cls(initial_location, tile_size, max_size, drifts=[])
+
     @classmethod
     def read_hdf5(cls, file):
         with h5py.File(file, "r") as hfile:
             trap_info = hfile["trap_info"]
             initial_locations = trap_info["trap_locations"][()]
-            drifts = trap_info["drifts"][()]
+            drifts = trap_info["drifts"][()].tolist()
             max_size = trap_info.attrs["max_size"]
             tile_size = trap_info.attrs["tile_size"]
         trap_locs = cls(initial_locations, tile_size, max_size=max_size)
         trap_locs.drifts = drifts
+        # trap_locs.n_processed = len(drifts)
         return trap_locs
 
 
 class TilerParameters(ParametersABC):
-    def __init__(
-        self, tile_size: int, ref_channel: str, ref_z: int, template_name: str = None
-    ):
-        self.tile_size = tile_size
-        self.ref_channel = ref_channel
-        self.ref_z = ref_z
-        self.template_name = template_name
 
-    @classmethod
-    def from_template(cls, template_name: str, ref_channel: str, ref_z: int):
-        return cls(template.shape[0], ref_channel, ref_z, template_path=template_name)
-
-    @classmethod
-    def default(cls):
-        return cls(117, "Brightfield", 0)
+    _defaults = {"tile_size": 117, "ref_channel": "Brightfield", "ref_z": 0}
 
 
 class Tiler(ProcessABC):
@@ -168,16 +162,23 @@ class Tiler(ProcessABC):
         return cls(image.data, image.metadata, parameters)
 
     @classmethod
-    def from_hdf5(cls, image, filepath):
+    def from_hdf5(cls, image, filepath, parameters=None):
         trap_locs = TrapLocations.read_hdf5(filepath)
         metadata = load_attributes(filepath)
-        metadata["channels"] = metadata["channels/channel"].tolist()
-        return cls(
+        metadata["channels"] = image.metadata["channels"]
+
+        if parameters is None:
+            parameters = TilerParameters.default()
+
+        tiler = cls(
             image.data,
             metadata,
-            TilerParameters.default(),
+            parameters,
             trap_locs=trap_locs,
         )
+        if hasattr(trap_locs, "drifts"):
+            tiler.n_processed = len(trap_locs.drifts)
+        return tiler
 
     @lru_cache(maxsize=2)
     def get_tc(self, t, c):
@@ -225,7 +226,8 @@ class Tiler(ProcessABC):
             if half_tile < x < max_size - half_tile
             and half_tile < y < max_size - half_tile
         ]
-        self.trap_locs = TrapLocations(trap_locs, tile_size)
+        self.trap_locs = TrapLocations.from_tiler_init(trap_locs, tile_size)
+        # self.trap_locs = TrapLocations(trap_locs, tile_size)
 
     def find_drift(self, tp):
         # TODO check that the drift doesn't move any tiles out of the image, remove them from list if so
@@ -234,7 +236,10 @@ class Tiler(ProcessABC):
             self.image[prev_tp, self.ref_channel, self.ref_z],
             self.image[tp, self.ref_channel, self.ref_z],
         )
-        self.trap_locs.drifts.append(drift)
+        if 0 < tp < len(self.trap_locs.drifts):
+            self.trap_locs.drifts[tp] = drift.tolist()
+        else:
+            self.trap_locs.drifts.append(drift.tolist())
 
     def get_tp_data(self, tp, c):
         traps = []
@@ -288,13 +293,21 @@ class Tiler(ProcessABC):
         return trap
 
     def run_tp(self, tp):
-        assert tp >= self.n_processed, "Time point already processed"
+        # assert tp >= self.n_processed, "Time point already processed"
         # TODO check contiguity?
-        if self.n_processed == 0:
+        if self.n_processed == 0 or not hasattr(self.trap_locs, "drifts"):
             self._initialise_traps(self.tile_size)
+
+        if hasattr(self.trap_locs, "drifts"):
+            drift_len = len(self.trap_locs.drifts)
+
+            if self.n_processed != drift_len:
+                raise (Exception("Tiler:N_processed and ndrifts don't match"))
+                self.n_processed = drift_len
+
         self.find_drift(tp)  # Get drift
         # update n_processed
-        self.n_processed += 1
+        self.n_processed = tp + 1
         # Return result for writer
         return self.trap_locs.to_dict(tp)
 
