@@ -1,19 +1,10 @@
-import os
-from pathlib import Path, PosixPath
-
-from collections.abc import Iterable
 import logging
 from time import perf_counter
 
-# from copy import copy
 from typing import Union, List, Dict, Callable
-from datetime import datetime
 
 import numpy as np
 import pandas as pd
-from scipy.sparse import dok_matrix, vstack, issparse
-from tqdm import tqdm
-
 
 from extraction.core.functions.loaders import (
     load_funs,
@@ -24,13 +15,10 @@ from extraction.core.functions.loaders import (
 from extraction.core.functions.defaults import exparams_from_meta
 from extraction.core.functions.distributors import trap_apply, reduce_z
 from extraction.core.functions.utils import depth
-
+from aliby.tile.tiler import Tiler
 from agora.abc import ProcessABC, ParametersABC
 from agora.io.writer import Writer, load_attributes
-from agora.io.cells import Cells
-from aliby.tile.tiler import Tiler
-
-import matplotlib.pyplot as plt
+from agora.io.cells import CellsLinear
 
 CELL_FUNS, TRAPFUNS, FUNS = load_funs()
 CUSTOM_FUNS, CUSTOM_ARGS = load_custom_args()
@@ -38,7 +26,7 @@ RED_FUNS = load_redfuns()
 MERGE_FUNS = load_mergefuns()
 
 # Assign datatype depending on the metric used
-m2type = {"mean": np.float32, "median": np.ubyte, "imBackground": np.ubyte}
+# m2type = {"mean": np.float32, "median": np.ubyte, "imBackground": np.ubyte}
 
 
 class ExtractorParameters(ParametersABC):
@@ -127,10 +115,6 @@ class Extractor(ProcessABC):
     def from_img(cls, parameters: ExtractorParameters, store: str, img_meta: tuple):
         return cls(parameters, store=store, tiler=Tiler(*img_meta))
 
-    # @classmethod
-    # def from_store(cls, parameters: ExtractorParameters, store: str, img_meta: tuple):
-    #     return cls(parameters, store=store, tiler=Tiler(*img_meta))
-
     @property
     def channels(self):
         if not hasattr(self, "_channels"):
@@ -272,9 +256,18 @@ class Extractor(ProcessABC):
         self, traps: Union[np.array, None], masks: list, red_metrics: dict, **kwargs
     ) -> dict:
         """
+        Wrapper to apply reduction and then extraction.
+
+        Parameters
+        ----------
         :param red_metrics: dict in which keys are reduction funcions and
         values are strings indicating the metric function
         :**kwargs: All other arguments, must include masks and traps.
+
+        Returns
+        ------
+        Dictionary of dataframes with the corresponding reductions and metrics nested.
+
         """
 
         reduced_traps = {}
@@ -296,8 +289,9 @@ class Extractor(ProcessABC):
         return d
 
     def reduce_dims(self, img: np.array, method=None) -> np.array:
-        # assert len(img.shape) == 3, "Incorrect number of dimensions"
-
+        """
+        Collapse a z-stack into a single file. It may perform a null operation.
+        """
         if method is None:
             return img
 
@@ -313,6 +307,8 @@ class Extractor(ProcessABC):
         **kwargs,
     ) -> dict:
         """
+        Extract individual time-point from images and masks
+
         :param tp: int timepoint from which to extract results
         :param tree: dict of dict {channel : {reduction_function : metrics}}
         :**kwargs: Must include masks and preferably labels.
@@ -324,7 +320,7 @@ class Extractor(ProcessABC):
         ch_tree = {ch: v for ch, v in tree.items() if ch != "general"}
         tree_chs = (*ch_tree,)
 
-        cells = Cells.hdf(self.local)
+        cells = CellsLinear(self.local)
 
         # labels
         if labels is None:
@@ -414,14 +410,12 @@ class Extractor(ProcessABC):
                     **kwargs,
                 )
 
-        del traps, masks
         return d
 
     def get_imgs(self, channel, traps, channels=None):
         """
         Returns the image from a correct source, either raw or bgsub
 
-
         :channel: str name of channel to get
         :img: ndarray (trap_id, channel, tp, tile_size, tile_size, n_zstacks) of standard channels
         :channels: List of channels
@@ -435,6 +429,12 @@ class Extractor(ProcessABC):
         elif channel in self.img_bgsub:
             return self.img_bgsub[channel]
 
+    def run_tp(self, tp, **kwargs):
+        """
+        Wrapper to add compatiblibility with other pipeline steps
+        """
+        return self.run(tps=[tp], **kwargs)
+
     def run(self, tree=None, tps: List[int] = None, save=True, **kwargs) -> dict:
 
         if tree is None:
